import"./vue-router.00a420cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="79f71d90-0fc0-42c6-9a1c-29cb01c18914",e._sentryDebugIdIdentifier="sentry-dbid-79f71d90-0fc0-42c6-9a1c-29cb01c18914")}catch{}})();const i=1e3,s=e=>{let n=null;return{startPolling:()=>{const t=async()=>{var o;try{!document.hidden&&!e.keepPollingOnOutOfFocus&&await e.task()}finally{n=setTimeout(t,(o=e.interval)!=null?o:i)}};t()},endPolling:()=>{n&&clearTimeout(n)}}};export{s as u};
//# sourceMappingURL=polling.b0dad0c1.js.map
