import{d,o as r,c as o,w as a,b as c,Z as u,u as s,dd as f,ey as i,eB as l,bP as p}from"./vue-router.00a420cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="cbd1ab1e-63a9-4827-81d0-e905d2c86c84",e._sentryDebugIdIdentifier="sentry-dbid-cbd1ab1e-63a9-4827-81d0-e905d2c86c84")}catch{}})();const y=d({__name:"AbstraButton",setup(e){return(t,n)=>(r(),o(s(p),i(l(t.$attrs)),{default:a(()=>[c(s(f),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[u(t.$slots,"default")]),_:3})]),_:3},16))}});export{y as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.b53c3ede.js.map
