import{S as c,dA as s,dB as i}from"./vue-router.00a420cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="f0f35797-cec3-4655-9d3d-4607e51ad8ff",e._sentryDebugIdIdentifier="sentry-dbid-f0f35797-cec3-4655-9d3d-4607e51ad8ff")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:d}=s(i),y=c(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:d,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(d.name,d),e.component(r.name,r),e.component(t.name,t),e.component(o.name,o),e)});export{y as D,r as M,o as Q,d as R,t as W};
//# sourceMappingURL=dayjs.237494aa.js.map
