import{P as k}from"./api.c5daba87.js";import{b as _}from"./workspaceStore.ea06441e.js";import{d as w,L as g,N as f,e as v,o as a,X as h,b as s,w as T,u as e,c as p,R as m,$ as K}from"./vue-router.00a420cb.js";import{K as R,_ as I,W as P,P as S,b as V}from"./WorkflowView.675f1ca3.js";import{A as c,T as x}from"./TabPane.c1aa8263.js";import"./Card.ccc71f20.js";import"./fetch.6ba1730a.js";import"./metadata.f1a74c77.js";import"./PhBug.vue.c45bf120.js";import"./PhCheckCircle.vue.33882b8f.js";import"./PhKanban.vue.46e0e517.js";import"./PhWebhooksLogo.vue.fba89849.js";import"./url.fed57a6c.js";import"./colorHelpers.a93840c7.js";import"./polling.b0dad0c1.js";import"./asyncComputed.eac0df71.js";import"./PhQuestion.vue.326c4148.js";import"./ant-design.c8a1aa1d.js";import"./index.b00d735b.js";import"./index.90096d68.js";import"./index.bc91e114.js";import"./CollapsePanel.64b5106a.js";import"./index.2f9de8bf.js";import"./index.f9b752d6.js";import"./Badge.84a2436a.js";import"./PhArrowCounterClockwise.vue.0c14a631.js";import"./Workflow.fd532f45.js";import"./validations.30f59e3c.js";import"./string.110ad283.js";import"./uuid.94206b3d.js";import"./index.15549573.js";import"./workspaces.5eeae11a.js";import"./record.149dcd57.js";import"./index.97b1eb2c.js";import"./PhArrowDown.vue.625056c7.js";import"./LoadingOutlined.63ba4c82.js";import"./DeleteOutlined.859dafad.js";import"./PhDownloadSimple.vue.c53acfa8.js";import"./utils.e4dc8aff.js";import"./LoadingContainer.5b237450.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="5ffe3e06-9098-4f84-819c-1074fa2fb3bc",t._sentryDebugIdIdentifier="sentry-dbid-5ffe3e06-9098-4f84-819c-1074fa2fb3bc")}catch{}})();const W={class:"threads-view"},A=w({__name:"Threads",setup(t){const r=_().authHeaders,b=new k(r),i=new S(r),u=new V(r),d=new g(f.array(f.string()),"kanban-selected-stages"),o=v("kanban");return(B,l)=>(a(),h("div",W,[s(e(x),{activeKey:o.value,"onUpdate:activeKey":l[0]||(l[0]=y=>o.value=y)},{default:T(()=>[s(e(c),{key:"kanban",tab:"Kanban View"}),s(e(c),{key:"table",tab:"Table View"}),s(e(c),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(a(),p(R,{key:0,"kanban-repository":e(i),"kanban-stages-storage":e(d),"stage-run-repository":e(u)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),o.value==="table"?(a(),p(I,{key:1,"kanban-repository":e(i)},null,8,["kanban-repository"])):m("",!0),o.value==="workflow"?(a(),p(P,{key:2,"kanban-repository":e(i),"workflow-api":e(b)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const ge=K(A,[["__scopeId","data-v-d6c18c3e"]]);export{ge as default};
//# sourceMappingURL=Threads.87011578.js.map
