import{E as y}from"./api.c5daba87.js";import{C as w}from"./ContentLayout.bd728007.js";import{d as c,L as g,N as d,e as _,o as a,c as i,w as l,b as n,u as o,R as s}from"./vue-router.00a420cb.js";import{K as v,_ as K,W as R,E,a as T}from"./WorkflowView.675f1ca3.js";import{A as p,T as V}from"./TabPane.c1aa8263.js";import"./fetch.6ba1730a.js";import"./metadata.f1a74c77.js";import"./PhBug.vue.c45bf120.js";import"./PhCheckCircle.vue.33882b8f.js";import"./PhKanban.vue.46e0e517.js";import"./PhWebhooksLogo.vue.fba89849.js";import"./polling.b0dad0c1.js";import"./asyncComputed.eac0df71.js";import"./PhQuestion.vue.326c4148.js";import"./ant-design.c8a1aa1d.js";import"./index.b00d735b.js";import"./index.90096d68.js";import"./index.bc91e114.js";import"./CollapsePanel.64b5106a.js";import"./index.2f9de8bf.js";import"./index.f9b752d6.js";import"./Badge.84a2436a.js";import"./PhArrowCounterClockwise.vue.0c14a631.js";import"./Workflow.fd532f45.js";import"./validations.30f59e3c.js";import"./string.110ad283.js";import"./uuid.94206b3d.js";import"./index.15549573.js";import"./workspaces.5eeae11a.js";import"./workspaceStore.ea06441e.js";import"./url.fed57a6c.js";import"./colorHelpers.a93840c7.js";import"./record.149dcd57.js";import"./index.97b1eb2c.js";import"./PhArrowDown.vue.625056c7.js";import"./Card.ccc71f20.js";import"./LoadingOutlined.63ba4c82.js";import"./DeleteOutlined.859dafad.js";import"./PhDownloadSimple.vue.c53acfa8.js";import"./utils.e4dc8aff.js";import"./LoadingContainer.5b237450.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="87b3ce10-e6a3-48f3-8cdd-00e13bd2d3e9",e._sentryDebugIdIdentifier="sentry-dbid-87b3ce10-e6a3-48f3-8cdd-00e13bd2d3e9")}catch{}})();const yo=c({__name:"WorkflowThreads",setup(e){const t=new E,m=new T,f=new g(d.array(d.string()),"kanban-selected-stages"),u=new y,r=_("kanban");return(W,b)=>(a(),i(w,{"full-width":""},{default:l(()=>[n(o(V),{activeKey:r.value,"onUpdate:activeKey":b[0]||(b[0]=k=>r.value=k)},{default:l(()=>[n(o(p),{key:"kanban",tab:"Kanban View"}),n(o(p),{key:"table",tab:"Table View"}),n(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),r.value==="kanban"?(a(),i(v,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(f),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),r.value==="table"?(a(),i(K,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),r.value==="workflow"?(a(),i(R,{key:2,"kanban-repository":o(t),"workflow-api":o(u)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{yo as default};
//# sourceMappingURL=WorkflowThreads.4650f082.js.map
