import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.b0fa996d.js";import{d as i,ea as s,o as m,c as a,u as d}from"./vue-router.00a420cb.js";import"./gateway.3775a912.js";import"./popupNotifcation.6aec82b8.js";import"./fetch.6ba1730a.js";import"./record.149dcd57.js";import"./SaveButton.40926371.js";import"./UnsavedChangesHandler.5403c18e.js";import"./ExclamationCircleOutlined.225726dc.js";import"./CrudView.ea3cf78e.js";import"./router.70041753.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.465b2cc4.js";import"./BookOutlined.df18764f.js";import"./url.fed57a6c.js";import"./PhDotsThreeVertical.vue.8b39bb89.js";import"./Badge.84a2436a.js";import"./index.b00d735b.js";import"./asyncComputed.eac0df71.js";import"./polling.b0dad0c1.js";import"./PhPencil.vue.46f29c2d.js";import"./index.3c9d36ac.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="0b7e955e-4768-4bd3-b20d-bafe968ec563",o._sentryDebugIdIdentifier="sentry-dbid-0b7e955e-4768-4bd3-b20d-bafe968ec563")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=s().params.projectId,t=new p(r);return(c,f)=>(m(),a(n,{"env-var-repository":d(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.a2069ff7.js.map
