import"./App.vue_vue_type_style_index_0_lang.91e56923.js";import{_ as m}from"./App.vue_vue_type_style_index_0_lang.91e56923.js";import"./workspaceStore.ea06441e.js";import"./vue-router.00a420cb.js";import"./url.fed57a6c.js";import"./colorHelpers.a93840c7.js";import"./PlayerConfigProvider.47c6242d.js";import"./index.15549573.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="def5a095-1875-4c16-bc7d-1fbd16ce3788",e._sentryDebugIdIdentifier="sentry-dbid-def5a095-1875-4c16-bc7d-1fbd16ce3788")}catch{}})();export{m as default};
//# sourceMappingURL=App.20cf0006.js.map
