import{b as r,u as n}from"./workspaceStore.ea06441e.js";import{W as c}from"./PlayerConfigProvider.47c6242d.js";import{d,g as i,r as u,u as a,o as f,c as p,w as l,R as _,b as m}from"./vue-router.00a420cb.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="bef8cba4-81ac-41a5-93ac-48d87b06ad5e",t._sentryDebugIdIdentifier="sentry-dbid-bef8cba4-81ac-41a5-93ac-48d87b06ad5e")}catch{}})();const h=d({__name:"App",setup(t){const o=r(),e=n();return e.actions.fetch(),i(()=>o.user,e.actions.fetch),(b,w)=>{const s=u("RouterView");return a(e).state.workspace?(f(),p(c,{key:0,"main-color":a(e).state.workspace.mainColor,background:a(e).state.workspace.theme,"font-family":a(e).state.workspace.fontFamily,locale:a(e).state.workspace.language},{default:l(()=>[m(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):_("",!0)}}});export{h as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.91e56923.js.map
