import{L as t}from"./Logo.759be485.js";import{d as a,o as n,c as r,u as d}from"./vue-router.00a420cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="9636162e-8dad-496c-a5de-9cc451bf9077",e._sentryDebugIdIdentifier="sentry-dbid-9636162e-8dad-496c-a5de-9cc451bf9077")}catch{}})();const i="/assets/logo.0faadfa2.svg",u=a({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(o,s)=>(n(),r(t,{"image-url":d(i),"brand-name":"Abstra","hide-text":o.hideText,size:o.size},null,8,["image-url","hide-text","size"]))}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.fdf2996c.js.map
