import{O as d}from"./workspaceStore.ea06441e.js";import{d as l,W as c,o as i,X as u,b as a,w as o,u as n,aF as s,d9 as f,d8 as b}from"./vue-router.00a420cb.js";import"./url.fed57a6c.js";import"./colorHelpers.a93840c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="33393b2c-c6e3-4b3c-a680-8b25d29c3778",e._sentryDebugIdIdentifier="sentry-dbid-33393b2c-c6e3-4b3c-a680-8b25d29c3778")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return c(async()=>{await new d().logoutCallback()}),(t,r)=>(i(),u("div",null,[a(n(f),null,{default:o(()=>[s("You're authenticated")]),_:1}),a(n(b),null,{default:o(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.4d873b17.js.map
