import{d as i,o as p,c as n,w as m,b as s,u as t}from"./vue-router.00a420cb.js";import"./editor.3a59ac0a.js";import{W as a}from"./workspaces.5eeae11a.js";import{C as d}from"./ContentLayout.bd728007.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.b0fa996d.js";import"./workspaceStore.ea06441e.js";import"./url.fed57a6c.js";import"./colorHelpers.a93840c7.js";import"./asyncComputed.eac0df71.js";import"./record.149dcd57.js";import"./gateway.3775a912.js";import"./popupNotifcation.6aec82b8.js";import"./fetch.6ba1730a.js";import"./SaveButton.40926371.js";import"./UnsavedChangesHandler.5403c18e.js";import"./ExclamationCircleOutlined.225726dc.js";import"./CrudView.ea3cf78e.js";import"./router.70041753.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.465b2cc4.js";import"./BookOutlined.df18764f.js";import"./PhDotsThreeVertical.vue.8b39bb89.js";import"./Badge.84a2436a.js";import"./index.b00d735b.js";import"./polling.b0dad0c1.js";import"./PhPencil.vue.46f29c2d.js";import"./index.3c9d36ac.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="16886b91-b177-464c-9f70-9bd67234c1c8",o._sentryDebugIdIdentifier="sentry-dbid-16886b91-b177-464c-9f70-9bd67234c1c8")}catch{}})();const F=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(e,u)=>(p(),n(d,null,{default:m(()=>[s(f,{"env-var-repository":t(r),mode:"editor","file-opener":t(a)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{F as default};
//# sourceMappingURL=EnvVarsEditor.0c225d5a.js.map
