import{d as a,o,X as s,b as d,u as r,bx as _,$ as c}from"./vue-router.00a420cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="af137f18-9fc6-4a92-85bf-f286ce6d8be4",e._sentryDebugIdIdentifier="sentry-dbid-af137f18-9fc6-4a92-85bf-f286ce6d8be4")}catch{}})();const f={class:"centered"},i=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",f,[d(r(_))]))}});const u=c(i,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.5b237450.js.map
