import{d as n,o as s,X as d,a,Z as r,ed as l,$ as _}from"./vue-router.00a420cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5eb92ea6-d037-4261-80f8-3a9693d80ec6",e._sentryDebugIdIdentifier="sentry-dbid-5eb92ea6-d037-4261-80f8-3a9693d80ec6")}catch{}})();const c={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(s(),d("div",c,[a("div",{class:l(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const f=_(u,[["__scopeId","data-v-6397d501"]]);export{f as C};
//# sourceMappingURL=ContentLayout.bd728007.js.map
