import{_ as f}from"./Login.vue_vue_type_script_setup_true_lang.fd75ebf6.js";import{b as _,u as m}from"./workspaceStore.ea06441e.js";import{d as l,eo as b,ea as y,o as g,X as w,b as k,u as i,$ as h}from"./vue-router.00a420cb.js";import"./Logo.759be485.js";import"./string.110ad283.js";import"./CircularLoading.03ce79e0.js";import"./index.15549573.js";import"./index.3c9d36ac.js";import"./url.fed57a6c.js";import"./colorHelpers.a93840c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="ef942fb9-ef73-4806-a4b0-6ea4a80efaf0",e._sentryDebugIdIdentifier="sentry-dbid-ef942fb9-ef73-4806-a4b0-6ea4a80efaf0")}catch{}})();const v={class:"runner"},I=l({__name:"Login",setup(e){const o=b(),r=y(),p=_(),s=m(),d=async()=>{await p.signUp();const{redirect:t,...a}=r.query;if(t){await o.push({path:t,query:a,params:r.params});return}o.push({name:"playerHome",query:a})};return(t,a)=>{var n,c,u;return g(),w("div",v,[k(f,{"logo-url":(c=(n=i(s).state.workspace)==null?void 0:n.logoUrl)!=null?c:void 0,"brand-name":(u=i(s).state.workspace)==null?void 0:u.brandName,onDone:d},null,8,["logo-url","brand-name"])])}}});const $=h(I,[["__scopeId","data-v-fc57ade6"]]);export{$ as default};
//# sourceMappingURL=Login.a39c13ba.js.map
