import{$ as a,o,X as n,Z as s,a as d,R as r}from"./vue-router.00a420cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b69487c1-537c-4ac6-85d9-01423cfaaef6",e._sentryDebugIdIdentifier="sentry-dbid-b69487c1-537c-4ac6-85d9-01423cfaaef6")}catch{}})();const c={},f={class:"base-layout"},i={class:"base-middle"},u={key:0,class:"base-footer"};function _(e,t){return o(),n("div",f,[s(e.$slots,"sidebar",{},void 0,!0),d("section",i,[s(e.$slots,"navbar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),n("section",u,[s(e.$slots,"footer",{},void 0,!0)])):r("",!0)])])}const y=a(c,[["render",_],["__scopeId","data-v-9ad5be20"]]);export{y as B};
//# sourceMappingURL=BaseLayout.ee42d4b1.js.map
