import{cI as n}from"./vue-router.00a420cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="f0a0e65d-42cc-4a6d-8573-ba42652f7f1b",e._sentryDebugIdIdentifier="sentry-dbid-f0a0e65d-42cc-4a6d-8573-ba42652f7f1b")}catch{}})();const o=(e,r,d)=>{n.error({message:e,description:r,onClick:d})};export{o as p};
//# sourceMappingURL=popupNotifcation.6aec82b8.js.map
