import{$ as t,r as a,o as c,c as s}from"./vue-router.00a420cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="5e03a3fd-4a7c-4643-aa73-d4caa541f98d",e._sentryDebugIdIdentifier="sentry-dbid-5e03a3fd-4a7c-4643-aa73-d4caa541f98d")}catch{}})();const d={};function r(e,o){const n=a("RouterView");return c(),s(n,{class:"router"})}const f=t(d,[["render",r],["__scopeId","data-v-3c2b9654"]]);export{f as default};
//# sourceMappingURL=Home.6fdd82ab.js.map
