import{k as i,T as n,m as r,P as o,C as d,M as p,s as c,n as s,p as m,q as u,t as f,v as g}from"./vue-router.00a420cb.js";import{s as b,c as y,a}from"./workspaceStore.ea06441e.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.91e56923.js";import"./url.fed57a6c.js";import"./colorHelpers.a93840c7.js";import"./PlayerConfigProvider.47c6242d.js";import"./index.15549573.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="8a27a11a-8bbd-46d4-a842-e491a8503995",t._sentryDebugIdIdentifier="sentry-dbid-8a27a11a-8bbd-46d4-a842-e491a8503995")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await b();const t=y(),e=i({render:()=>m(l)});n.init(),r(e,a),w.init(),e.use(a),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",c),s(e,u),s(e,f),s(e,g)})();
//# sourceMappingURL=player.3f286b37.js.map
